@@ -42,7 +42,9 @@ namespace Twitterizer.Commands
     /// The Create Favorite Command class. Favorites the status specified in the ID parameter as the authenticating user. Returns the favorite status when successful.
     /// </summary>
     [AuthorizedCommandAttribute]
+#if !SILVERLIGHT
     [Serializable]
+#endif
     internal sealed class CreateFavoriteCommand : TwitterCommand<TwitterStatus>
     {
         /// <summary>
@@ -52,7 +54,7 @@ namespace Twitterizer.Commands
         /// <param name="statusId">The status id.</param>
         /// <param name="options">The options.</param>
         public CreateFavoriteCommand(OAuthTokens tokens, decimal statusId, OptionalProperties options) :
-            base(HTTPVerb.POST, string.Format(CultureInfo.InvariantCulture.NumberFormat, "/favorites/{0}/create.json", statusId), tokens, options)
+            base(HTTPVerb.POST, string.Format(CultureInfo.InvariantCulture.NumberFormat, "favorites/create.json?id={0}", statusId), tokens, options)
         {
             if (tokens == null)
             {
