@@ -42,7 +42,9 @@ namespace Twitterizer.Commands
     /// The delete friendship command class.
     /// </summary>
     [AuthorizedCommandAttribute]
+#if !SILVERLIGHT
     [Serializable]
+#endif
     internal sealed class DeleteFriendshipCommand : Core.TwitterCommand<TwitterUser>
     {
         /// <summary>
@@ -93,7 +95,7 @@ namespace Twitterizer.Commands
         {
             if (this.UserId > 0)
             {
-                this.RequestParameters.Add("user_id", this.UserId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("user_id", this.UserId.ToString("#"));
             }
             else if (!string.IsNullOrEmpty(this.UserName))
             {
