@@ -36,6 +36,7 @@ namespace Twitterizer
     using System;
     using System.Collections.ObjectModel;
     using System.Linq;
+    using System.Runtime.Serialization;
     using Newtonsoft.Json;
 
     /// <summary>
@@ -44,6 +45,7 @@ namespace Twitterizer
 #if !SILVERLIGHT
     [Serializable]
 #endif
+    [DataContract]
     public class Coordinate
     {
         /// <summary>
@@ -102,11 +104,11 @@ namespace Twitterizer
                     {
                         return null;
                     }
-
-                    int depth = reader.Depth + 1;
+                    
+                    //int depth = reader.Depth + 1;
                     double count = 1;
 
-                    while (reader.Read() && reader.Depth >= startDepth)
+                    while (reader.Read() && reader.Depth > startDepth)
                     {
                         if (new[] { JsonToken.StartArray, JsonToken.EndArray }.Contains(reader.TokenType))
                             continue;
@@ -116,16 +118,15 @@ namespace Twitterizer
                         if (count % 2 > 0)
                         {
                             result.Add(new Coordinate());
-                            result[itemIndex].Latitude = (double)reader.Value;
+                            result[itemIndex].Latitude = Convert.ToDouble(reader.Value);
                         }
                         else
                         {
-                            result[itemIndex].Longitude = (double)reader.Value;
+                            result[itemIndex].Longitude = Convert.ToDouble(reader.Value);
                         }
 
                         count++;
-                    }
-
+                    }                    
                     return result;
                 }
                 catch
