@@ -42,7 +42,9 @@ namespace Twitterizer.Commands
     /// Add a member to a list. The authenticated user must own the list to be able to add members to it. Lists are limited to having 500 members.
     /// </summary>
     [AuthorizedCommand]
+#if !SILVERLIGHT
     [Serializable]
+#endif
     internal class AddListMemberCommand : TwitterCommand<TwitterList>
     {
         /// <summary>
@@ -53,8 +55,8 @@ namespace Twitterizer.Commands
         /// <param name="listId">The list id.</param>
         /// <param name="userId">The user id.</param>
         /// <param name="options">The options.</param>
-        public AddListMemberCommand(OAuthTokens requestTokens, string ownerUsername, decimal listId, decimal userId, OptionalProperties options)
-            : base(HTTPVerb.POST, string.Format(CultureInfo.CurrentCulture, "/{0}/{1}/members.json", ownerUsername, listId), requestTokens, options)
+        public AddListMemberCommand(OAuthTokens requestTokens, string ownerUsername, string listId, decimal userId, OptionalProperties options)
+            : base(HTTPVerb.POST, string.Format(CultureInfo.CurrentCulture, "{0}/{1}/members.json", ownerUsername, listId), requestTokens, options)
         {
             if (requestTokens == null)
             {
@@ -66,7 +68,7 @@ namespace Twitterizer.Commands
                 throw new ArgumentNullException("ownerUsername");
             }
 
-            if (listId <= 0)
+            if (string.IsNullOrEmpty(listId))
             {
                 throw new ArgumentNullException("listId");
             }
@@ -90,7 +92,7 @@ namespace Twitterizer.Commands
         /// </summary>
         public override void Init()
         {
-            this.RequestParameters.Add("user_id", this.UserId.ToString(CultureInfo.InvariantCulture.NumberFormat));
+            this.RequestParameters.Add("id", this.UserId.ToString("#"));
         }
     }
 }
