@@ -1,9 +1,4 @@
-﻿using System;
-using System.Collections.Generic;
-using System.Linq;
-using System.Text;
-
-namespace Twitterizer.Commands
+﻿namespace Twitterizer.Commands
 {
     [Core.AuthorizedCommand]
     internal class DestroyListSubscriber : Core.TwitterCommand<TwitterList>
@@ -34,7 +29,7 @@ namespace Twitterizer.Commands
         /// <remarks></remarks>
         public override void Init()
         {
-            this.RequestParameters.Add("list_id", this.ListId.ToString());
+            this.RequestParameters.Add("list_id", this.ListId.ToString("#"));
         }
     }
 }
