@@ -42,6 +42,7 @@ namespace Twitterizer.Commands
 #if !SILVERLIGHT
     [Serializable]
 #endif
+    [AuthorizedCommandAttribute]
     internal sealed class SearchCommand : TwitterCommand<TwitterSearchResultCollection>
     {
         #region Constructors
@@ -52,7 +53,7 @@ namespace Twitterizer.Commands
         /// <param name="query">The query.</param>
         /// <param name="options">The options.</param>
         public SearchCommand(OAuthTokens requestTokens, string query, SearchOptions options)
-            : base(HTTPVerb.GET, "search.json", requestTokens, options)
+            : base(HTTPVerb.GET, "search/tweets.json", requestTokens, options)
         {
             if (string.IsNullOrEmpty(query))
             {
@@ -103,27 +104,17 @@ namespace Twitterizer.Commands
 
             if (options.MaxId > 0)
             {
-                this.RequestParameters.Add("max_id", options.MaxId.ToString(unitedStatesEnglishCulture));
+                this.RequestParameters.Add("max_id", options.MaxId.ToString("#"));
             }
 
-            if (options.NumberPerPage > 0)
+            if (options.Count > 0)
             {
-                this.RequestParameters.Add("rpp", options.NumberPerPage.ToString(unitedStatesEnglishCulture));
-            }
-
-            if (options.PageNumber > 0)
-            {
-                this.RequestParameters.Add("page", options.PageNumber.ToString(unitedStatesEnglishCulture));
-            }
-
-            if (options.SinceDate > new DateTime())
-            {
-                this.RequestParameters.Add("since", options.SinceDate.ToString("yyyy-MM-dd", unitedStatesEnglishCulture));
+                this.RequestParameters.Add("count", options.Count.ToString(unitedStatesEnglishCulture));
             }
 
             if (options.SinceId > 0)
             {
-                this.RequestParameters.Add("since_id", options.SinceId.ToString(unitedStatesEnglishCulture));
+                this.RequestParameters.Add("since_id", options.SinceId.ToString("#"));
             }
 
             if (!string.IsNullOrEmpty(options.GeoCode))
@@ -131,11 +122,6 @@ namespace Twitterizer.Commands
                 this.RequestParameters.Add("geocode", options.GeoCode);
             }
 
-            if (options.PrefixUsername)
-            {
-                this.RequestParameters.Add("show_user", "true");
-            }
-
             if (options.UntilDate > new DateTime())
             {
                 this.RequestParameters.Add("until", options.UntilDate.ToString("{0:yyyy-MM-dd}", unitedStatesEnglishCulture));
@@ -154,9 +140,6 @@ namespace Twitterizer.Commands
                     break;
             }
 
-            if (options.WithTwitterUserID)
-                this.RequestParameters.Add("with_twitter_user_id", "true");
-
             if (options.IncludeEntities)
                 this.RequestParameters.Add("include_entities", "true");
         }
