@@ -74,15 +74,17 @@ namespace Twitterizer.Commands
             }
 
             if (options.SinceStatusId > 0)
-                this.RequestParameters.Add("since_id", options.SinceStatusId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("since_id", options.SinceStatusId.ToString("#"));
 
             if (options.MaxStatusId > 0)
-                this.RequestParameters.Add("max_id", options.MaxStatusId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("max_id", options.MaxStatusId.ToString("#"));
 
             if (options.Count > 0)
                 this.RequestParameters.Add("count", options.Count.ToString(CultureInfo.InvariantCulture));
 
             this.RequestParameters.Add("page", options.Page > 0 ? options.Page.ToString(CultureInfo.InvariantCulture) : "1");
+
+            this.RequestParameters.Add("include_entities", "true");
         }
     }
 }
