@@ -41,9 +41,11 @@ namespace Twitterizer.Commands
     /// <summary>
     /// The command to obtain followers of a user.
     /// </summary>
+#if !SILVERLIGHT
     [Serializable]
+#endif
     internal sealed class FollowersCommand :
-        Core.CursorPagedCommand<TwitterUserCollection>
+        Core.TwitterCommand<TwitterUserCollection>
     {
         /// <summary>
         /// Initializes a new instance of the <see cref="FollowersCommand"/> class.
@@ -71,12 +73,8 @@ namespace Twitterizer.Commands
         /// </summary>
         public override void Init()
         {
-            if (this.Cursor <= 0)
-            {
-                this.Cursor = -1;
-            }
-
-            this.RequestParameters.Add("cursor", this.Cursor.ToString(CultureInfo.CurrentCulture));
+            // Default values
+            this.RequestParameters.Add("cursor", "-1");
 
             // Handle optional parameters
             FollowersOptions options = this.OptionalProperties as FollowersOptions;
@@ -87,22 +85,14 @@ namespace Twitterizer.Commands
             }
 
             if (options.UserId > 0)
-                this.RequestParameters.Add("user_id", options.UserId.ToString(CultureInfo.CurrentCulture));
+                this.RequestParameters.Add("user_id", options.UserId.ToString("#"));
 
             if (!string.IsNullOrEmpty(options.ScreenName))
                 this.RequestParameters.Add("screen_name", options.ScreenName);
-        }
 
-        /// <summary>
-        /// Clones this instance.
-        /// </summary>
-        /// <returns>A cloned command object.</returns>
-        internal override Twitterizer.Core.TwitterCommand<TwitterUserCollection> Clone()
-        {
-            FollowersCommand newCommand = new FollowersCommand(this.Tokens, this.OptionalProperties as FollowersOptions);
-            newCommand.Cursor = this.Cursor;
-
-            return newCommand;
+            // Override the default
+            if (options.Cursor != 0)
+                this.RequestParameters["cursor"] = options.Cursor.ToString(CultureInfo.CurrentCulture);
         }
     }
 }
