@@ -41,8 +41,10 @@ namespace Twitterizer.Commands
     /// <summary>
     /// The command to obtain followers of a user.
     /// </summary>
+#if !SILVERLIGHT
     [Serializable]
-    internal sealed class FriendsCommand : CursorPagedCommand<TwitterUserCollection>
+#endif
+    internal sealed class FriendsCommand : TwitterCommand<TwitterUserCollection>
     {
         /// <summary>
         /// Initializes a new instance of the <see cref="FriendsCommand"/> class.
@@ -60,38 +62,25 @@ namespace Twitterizer.Commands
         /// </summary>
         public override void Init()
         {
+            // Default values
+            this.RequestParameters.Add("cursor", "-1");
+
             FriendsOptions options = this.OptionalProperties as FriendsOptions;
 
-            if (options != null)
+            if (options == null)
             {
-                if (options.UserId > 0)
-                    this.RequestParameters.Add("user_id", options.UserId.ToString(CultureInfo.CurrentCulture));
-
-                if (!string.IsNullOrEmpty(options.ScreenName))
-                    this.RequestParameters.Add("screen_name", options.ScreenName);
-
-                if (options.Cursor != 0)
-                    this.Cursor = options.Cursor;
+                return;
             }
 
-            if (this.Cursor == 0)
-            {
-                this.Cursor = -1;
-            }
+            if (options.UserId > 0)
+                this.RequestParameters.Add("user_id", options.UserId.ToString("#"));
 
-            this.RequestParameters.Add("cursor", this.Cursor.ToString(CultureInfo.CurrentCulture));
-        }
+            if (!string.IsNullOrEmpty(options.ScreenName))
+                this.RequestParameters.Add("screen_name", options.ScreenName);
 
-        /// <summary>
-        /// Clones this instance.
-        /// </summary>
-        /// <returns>A cloned command object.</returns>
-        internal override Twitterizer.Core.TwitterCommand<TwitterUserCollection> Clone()
-        {
-            FriendsCommand newCommand = new FriendsCommand(this.Tokens, this.OptionalProperties as FriendsOptions);
-            newCommand.Cursor = this.Cursor;
-
-            return newCommand;
+            // Override the default
+            if (options.Cursor != 0)
+                this.RequestParameters["cursor"] = options.Cursor.ToString(CultureInfo.CurrentCulture);
         }
     }
 }
