@@ -34,82 +34,85 @@
 namespace Twitterizer
 {
     using System;
-    using System.ComponentModel;
     using System.Diagnostics;
+#if !SILVERLIGHT
     using System.Drawing;
+#endif
     using Newtonsoft.Json;
-    using Twitterizer.Core;
+    using Core;
+    using System.Runtime.Serialization;
 
     /// <include file='TwitterUser.xml' path='TwitterUser/TwitterUser/*'/>
     [JsonObject(MemberSerialization.OptIn)]
     [DebuggerDisplay("@{ScreenName}")]
+#if !SILVERLIGHT
     [Serializable]
-    public class TwitterUser : Core.TwitterObject
+#endif
+    [DataContract]
+    public class TwitterUser : TwitterObject
     {
-        public static void Show(string username, OptionalProperties options, Action<TwitterUser> function)
-        {
-            Func<string, OptionalProperties, TwitterUser> methodToCall = new Func<string, OptionalProperties, TwitterUser>(Show);
-
-            AsyncOperation operation = AsyncOperationManager.CreateOperation(null);
-            methodToCall.BeginInvoke(
-                username,
-                options,
-                (AsyncCallback)((IAsyncResult result) =>
-                    {
-                        function(methodToCall.EndInvoke(result));
-                    }), 
-                null);
-        }
-
-
-        /// <summary>
-        /// Initializes a new instance of the <see cref="TwitterUser"/> class.
-        /// </summary>
-        public TwitterUser()
-            : base()
-        {
-        }
-
-        /// <summary>
-        /// Gets a value indicating whether this instance is empty.
-        /// </summary>
-        /// <value><c>true</c> if this instance is empty; otherwise, <c>false</c>.</value>
-        internal virtual bool IsEmpty { get { return false; } }
-
         #region Properties
         /// <summary>
         /// Gets or sets the User ID.
         /// </summary>
         /// <value>The User ID.</value>
-        [JsonProperty(PropertyName = "id")]
+        [DataMember, JsonProperty(PropertyName = "id")]
         public decimal Id { get; set; }
 
+        /// <summary>
+        /// Gets or sets the string id.
+        /// </summary>
+        /// <value>The string id.</value>
+        [DataMember, JsonProperty(PropertyName = "id_str")]
+        public string StringId { get; set; }
+
         /// <summary>
         /// Gets or sets the name of the user.
         /// </summary>
         /// <value>The name of the user.</value>
-        [JsonProperty(PropertyName = "name")]
+        [DataMember, JsonProperty(PropertyName = "name")]
         public string Name { get; set; }
 
         /// <summary>
         /// Gets or sets the location.
         /// </summary>
         /// <value>The location.</value>
-        [JsonProperty(PropertyName = "location")]
+        [DataMember, JsonProperty(PropertyName = "location")]
         public string Location { get; set; }
 
         /// <summary>
         /// Gets or sets the description.
         /// </summary>
         /// <value>The description.</value>
-        [JsonProperty(PropertyName = "description")]
+        [DataMember, JsonProperty(PropertyName = "description")]
         public string Description { get; set; }
 
+        /// <summary>
+        /// Gets or sets a value indicating whether the user has not altered the theme or background of their profile.
+        /// </summary>
+        /// <value><c>false</c> if the user has altered the theme or background of their profile; otherwise, <c>true</c>.</value>
+        [DataMember, JsonProperty(PropertyName = "default_profile")]
+        public bool IsDefaultProfile { get; set; }
+
+        /// <summary>
+        /// Gets or sets a value indicating whether the user has not uploaded their own avatar and a default egg avatar is used instead.
+        /// </summary>
+        /// <value><c>false</c> if the user has uploaded their own avatar and a default egg avatar is used instead; otherwise, <c>true</c>.</value>
+        [DataMember, JsonProperty(PropertyName = "default_profile_image")]
+        public bool IsDefaultProfileImage { get; set; }
+
+        /// <summary>
+        /// Gets or sets a value indicating whether this user is a translator.
+        /// </summary>
+        /// <value><c>true</c> if this user is translator; otherwise, <c>false</c>.</value>
+        [DataMember, JsonProperty(PropertyName = "is_translator")]
+        public bool IsTranslator { get; set; }
+
         /// <summary>
         /// Gets or sets the status.
         /// </summary>
         /// <value>The status.</value>
-        [JsonProperty(PropertyName = "status")]
+        [DataMember, JsonProperty(PropertyName = "status")]
         public TwitterStatus Status { get; set; }
 
         /// <summary>
@@ -118,87 +121,63 @@ namespace Twitterizer
         /// <value>The created date.</value>
         [JsonProperty(PropertyName = "created_at")]
         [JsonConverter(typeof(TwitterizerDateConverter))]
+        [DataMember]
         public DateTime? CreatedDate { get; set; }
 
         /// <summary>
         /// Gets or sets the time zone.
         /// </summary>
         /// <value>The time zone.</value>
-        [JsonProperty(PropertyName = "time_zone")]
+        [DataMember, JsonProperty(PropertyName = "time_zone")]
         public string TimeZone { get; set; }
 
         /// <summary>
         /// Gets or sets the number of followers.
         /// </summary>
         /// <value>The number of followers.</value>
-        [JsonProperty(PropertyName = "followers_count")]
+        [DataMember, JsonProperty(PropertyName = "followers_count")]
         public long? NumberOfFollowers { get; set; }
 
         /// <summary>
         /// Gets or sets the number of statuses.
         /// </summary>
         /// <value>The number of statuses.</value>
-        [JsonProperty(PropertyName = "statuses_count")]
+        [DataMember, JsonProperty(PropertyName = "statuses_count")]
         public long NumberOfStatuses { get; set; }
 
         /// <summary>
         /// Gets or sets the number of friends.
         /// </summary>
         /// <value>The number of friends.</value>
-        [JsonProperty(PropertyName = "friends_count")]
+        [DataMember, JsonProperty(PropertyName = "friends_count")]
         public long NumberOfFriends { get; set; }
 
         /// <summary>
         /// Gets or sets a value indicating whether the user has enabled contributors access to his or her account.
         /// </summary>
         /// <value>The is contributors enabled value.</value>
-        [JsonProperty(PropertyName = "contributors_enabled")]
+        [DataMember, JsonProperty(PropertyName = "contributors_enabled")]
         public bool IsContributorsEnabled { get; set; }
 
         /// <summary>
         /// Gets or sets the language.
         /// </summary>
         /// <value>The language.</value>
-        [JsonProperty(PropertyName = "lang")]
+        [DataMember, JsonProperty(PropertyName = "lang")]
         public string Language { get; set; }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether the user receives notifications.
-        /// </summary>
-        /// <value>
-        /// <c>true</c> if the user receives notifications; otherwise, <c>false</c>.
-        /// </value>
-        [JsonProperty(PropertyName = "notifications")]
-        public bool? DoesReceiveNotifications { get; set; }
-
         /// <summary>
         /// Gets or sets the screenname.
         /// </summary>
         /// <value>The screenname.</value>
-        [JsonProperty(PropertyName = "screen_name")]
+        [DataMember, JsonProperty(PropertyName = "screen_name")]
         public string ScreenName { get; set; }
 
-        /// <summary>
-        /// Gets or sets a value indicating whether the authenticated user is following this user.
-        /// </summary>
-        /// <value>
-        /// <c>true</c> if the authenticated user is following this user; otherwise, <c>false</c>.
-        /// </value>
-        [JsonProperty(PropertyName = "following")]
-        public bool? IsFollowing { get; set; }
-
-        /// <summary>
-        /// Gets or sets the a value indicating whether the authenticated user is followed by this user.
-        /// </summary>
-        /// <value>The is followed by.</value>
-        [JsonProperty(PropertyName = "followed_by")]
-        public bool? IsFollowedBy { get; set; }
-
         /// <summary>
         /// Gets or sets the number of favorites.
         /// </summary>
         /// <value>The number of favorites.</value>
-        [JsonProperty(PropertyName = "favourites_count")]
+        [DataMember, JsonProperty(PropertyName = "favourites_count")]
         public long NumberOfFavorites { get; set; }
 
         /// <summary>
@@ -207,7 +186,7 @@ namespace Twitterizer
         /// <value>
         /// <c>true</c> if this user is protected; otherwise, <c>false</c>.
         /// </value>
-        [JsonProperty(PropertyName = "protected")]
+        [DataMember, JsonProperty(PropertyName = "protected")]
         public bool IsProtected { get; set; }
 
         /// <summary>
@@ -216,50 +195,75 @@ namespace Twitterizer
         /// <value>
         /// <c>true</c> if this user is geo enabled; otherwise, <c>false</c>.
         /// </value>
-        [JsonProperty(PropertyName = "geo_enabled")]
+        [DataMember, JsonProperty(PropertyName = "geo_enabled")]
         public bool? IsGeoEnabled { get; set; }
 
+        /// <summary>
+        /// Gets or sets the countries the user is withheld from.
+        /// </summary>
+        /// <value>The countries withheld from.</value>
+        /// <remarks>See also: https://dev.twitter.com/blog/new-withheld-content-fields-api-responses </remarks>
+        [DataMember, JsonProperty(PropertyName = "withheld_in_countries")]
+        public string CountriesWithheld { get; set; }
+
+        /// <summary>
+        /// Gets or sets a value that indicates whether the content being withheld is the "status" or a "user."
+        /// </summary>
+        /// <value>The withheld scope.</value>
+        /// <remarks>See also: https://dev.twitter.com/blog/new-withheld-content-fields-api-responses </remarks>
+        [DataMember, JsonProperty(PropertyName = "withheld_scope")]
+        public string WithheldScope { get; set; }
+
         /// <summary>
         /// Gets or sets the time zone offset.
         /// </summary>
         /// <value>The time zone offset.</value>
         /// <remarks>Also called the Coordinated Universal Time (UTC) offset.</remarks>
-        [JsonProperty(PropertyName = "utc_offset")]
+        [DataMember, JsonProperty(PropertyName = "utc_offset")]
         public double? TimeZoneOffset { get; set; }
 
         /// <summary>
         /// Gets or sets the user's website.
         /// </summary>
         /// <value>The website address.</value>
-        [JsonProperty(PropertyName = "url")]
+        [DataMember, JsonProperty(PropertyName = "url")]
         public string Website { get; set; }
 
         /// <summary>
         /// Gets or sets the listed count.
         /// </summary>
         /// <value>The listed count.</value>
-        [JsonProperty(PropertyName = "listed_count")]
+        [DataMember, JsonProperty(PropertyName = "listed_count")]
         public int ListedCount { get; set; }
 
         /// <summary>
         /// Gets or sets a value indicating whether [follow request sent].
         /// </summary>
         /// <value><c>true</c> if [follow request sent]; otherwise, <c>false</c>.</value>
-        [JsonProperty(PropertyName = "follow_request_sent")]
+        [DataMember, JsonProperty(PropertyName = "follow_request_sent")]
         public bool? FollowRequestSent { get; set; }
 
+        /// <summary>
+        /// Gets or sets a value indicating whether the user is verified.
+        /// </summary>
+        /// <value><c>true</c> if the user is verified; otherwise, <c>false</c>.</value>
+        [DataMember, JsonProperty(PropertyName = "verified")]
+        public bool? Verified { get; set; }
+
         #region Profile Layout Properties
         /// <summary>
         /// Gets or sets the color of the profile background.
         /// </summary>
         /// <value>The color of the profile background.</value>
-        [JsonProperty(PropertyName = "profile_background_color")]
+        [DataMember, JsonProperty(PropertyName = "profile_background_color")]
         public string ProfileBackgroundColorString { get; set; }
 
+#if !SILVERLIGHT
         /// <summary>
         /// Gets the color of the profile background.
         /// </summary>
         /// <value>The color of the profile background.</value>
+        [DataMember]
         public Color ProfileBackgroundColor
         {
             get
@@ -267,27 +271,29 @@ namespace Twitterizer
                 return ConversionUtility.FromTwitterString(this.ProfileBackgroundColorString);
             }
         }
-
+#endif
         /// <summary>
         /// Gets or sets a value indicating whether this user's profile background image is tiled.
         /// </summary>
         /// <value>
         /// <c>true</c> if this user's profile background image is tiled; otherwise, <c>false</c>.
         /// </value>
-        [JsonProperty(PropertyName = "profile_background_tile")]
+        [DataMember, JsonProperty(PropertyName = "profile_background_tile")]
         public bool? IsProfileBackgroundTiled { get; set; }
 
         /// <summary>
         /// Gets or sets the color of the profile link.
         /// </summary>
         /// <value>The color of the profile link.</value>
-        [JsonProperty(PropertyName = "profile_link_color")]
+        [DataMember, JsonProperty(PropertyName = "profile_link_color")]
         public string ProfileLinkColorString { get; set; }
 
+#if !SILVERLIGHT
         /// <summary>
         /// Gets the color of the profile link.
         /// </summary>
         /// <value>The color of the profile link.</value>
+        [DataMember]
         public Color ProfileLinkColor
         {
             get
@@ -295,25 +301,43 @@ namespace Twitterizer
                 return ConversionUtility.FromTwitterString(this.ProfileLinkColorString);
             }
         }
+#endif
 
         /// <summary>
         /// Gets or sets the profile background image location.
         /// </summary>
         /// <value>The profile background image location.</value>
-        [JsonProperty(PropertyName = "profile_background_image_url")]
+        [DataMember, JsonProperty(PropertyName = "profile_background_image_url")]
         public string ProfileBackgroundImageLocation { get; set; }
 
+        /// <summary>
+        /// Gets or sets a value indicating whether the user wants their uploaded background image to be used.
+        /// </summary>
+        /// <value><c>true</c> if the user wants their uploaded background image to be used; otherwise, <c>false</c>.</value>
+        [DataMember, JsonProperty(PropertyName = "profile_use_background_image")]
+        public bool UseProfileBackgroundImage { get; set; }
+
+        /// <summary>
+        /// Gets or sets the HTTPS-based URL pointing to the standard web representation of the user's uploaded profile banner.
+        /// </summary>
+        /// <remarks>By adding a final path element of the URL, you can obtain different image sizes optimized for specific displays. See also: https://dev.twitter.com/docs/user-profile-images-and-banners </remarks>
+        /// <value>The profile banner location.</value>
+        [DataMember, JsonProperty(PropertyName = "profile_banner_url")]
+        public string ProfileBannerLocation { get; set; }
+
         /// <summary>
         /// Gets or sets the color of the profile text.
         /// </summary>
         /// <value>The color of the profile text.</value>
-        [JsonProperty(PropertyName = "profile_text_color")]
+        [DataMember, JsonProperty(PropertyName = "profile_text_color")]
         public string ProfileTextColorString { get; set; }
 
+#if !SILVERLIGHT
         /// <summary>
         /// Gets the color of the profile text.
         /// </summary>
         /// <value>The color of the profile text.</value>
+        [DataMember]
         public Color ProfileTextColor
         {
             get
@@ -321,25 +345,35 @@ namespace Twitterizer
                 return ConversionUtility.FromTwitterString(this.ProfileTextColorString);
             }
         }
+#endif
 
         /// <summary>
         /// Gets or sets the profile image location.
         /// </summary>
         /// <value>The profile image location.</value>
-        [JsonProperty(PropertyName = "profile_image_url")]
+        [DataMember, JsonProperty(PropertyName = "profile_image_url")]
         public string ProfileImageLocation { get; set; }
 
+        /// <summary>
+        /// Gets or sets the secure profile image location (https).
+        /// </summary>
+        /// <value>The profile image location.</value>
+        [DataMember, JsonProperty(PropertyName = "profile_image_url_https")]
+        public string ProfileImageSecureLocation { get; set; }
+
         /// <summary>
         /// Gets or sets the color of the profile sidebar border.
         /// </summary>
         /// <value>The color of the profile sidebar border.</value>
-        [JsonProperty(PropertyName = "profile_sidebar_border_color")]
+        [DataMember, JsonProperty(PropertyName = "profile_sidebar_border_color")]
         public string ProfileSidebarBorderColorString { get; set; }
 
+#if !SILVERLIGHT
         /// <summary>
         /// Gets the color of the profile sidebar border.
         /// </summary>
         /// <value>The color of the profile sidebar border.</value>
+        [DataMember]
         public Color ProfileSidebarBorderColor
         {
             get
@@ -347,141 +381,171 @@ namespace Twitterizer
                 return ConversionUtility.FromTwitterString(this.ProfileSidebarBorderColorString);
             }
         }
+#endif
+
+        /// <summary>
+        /// Gets or sets the profile sidebar fill color string.
+        /// </summary>
+        /// <value>The profile sidebar fill color string.</value>
+        [DataMember, JsonProperty(PropertyName = "profile_sidebar_fill_color")]
+        public string ProfileSidebarFillColorString { get; set; }
+
+#if !SILVERLIGHT
+        /// <summary>
+        /// Gets the color of the profile sidebar fill.
+        /// </summary>
+        /// <value>The color of the profile sidebar fill.</value>
+        [DataMember]
+        public Color ProfileSidebarFillColor
+        {
+            get
+            {
+                return ConversionUtility.FromTwitterString(this.ProfileSidebarFillColorString);
+            }
+        }
+#endif
         #endregion
 
         #endregion
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="ByIDWithTokensAndOptions"]/*'/>
-        public static TwitterUser Show(OAuthTokens tokens, decimal id, OptionalProperties options)
+        public static TwitterResponse<TwitterUser> Show(OAuthTokens tokens, decimal id, OptionalProperties options)
         {
             Commands.ShowUserCommand command = new Commands.ShowUserCommand(tokens, id, string.Empty, options);
 
-            return Core.CommandPerformer<TwitterUser>.PerformAction(command);
+            return Core.CommandPerformer.PerformAction(command);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="ByIDWithOptions"]/*'/>
-        public static TwitterUser Show(decimal id, OptionalProperties options)
+        public static TwitterResponse<TwitterUser> Show(decimal id, OptionalProperties options)
         {
             return Show(null, id, options);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="ByIDWithTokens"]/*'/>
-        public static TwitterUser Show(OAuthTokens tokens, decimal id)
+        public static TwitterResponse<TwitterUser> Show(OAuthTokens tokens, decimal id)
         {
             return Show(tokens, id, null);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="ByID"]/*'/>
-        public static TwitterUser Show(decimal id)
+        public static TwitterResponse<TwitterUser> Show(decimal id)
         {
             return Show(null, id, null);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="ByUsernameWithTokensAndOptions"]/*'/>
-        public static TwitterUser Show(OAuthTokens tokens, string username, OptionalProperties options)
+        public static TwitterResponse<TwitterUser> Show(OAuthTokens tokens, string username, OptionalProperties options)
         {
             Commands.ShowUserCommand command = new Commands.ShowUserCommand(tokens, 0, username, options);
 
-            return Core.CommandPerformer<TwitterUser>.PerformAction(command);
+            return Core.CommandPerformer.PerformAction(command);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="ByUsernameWithOptions"]/*'/>
-        public static TwitterUser Show(string username, OptionalProperties options)
+        public static TwitterResponse<TwitterUser> Show(string username, OptionalProperties options)
         {
             return Show(null, username, options);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="ByUsernameWithTokens"]/*'/>
-        public static TwitterUser Show(OAuthTokens tokens, string username)
+        public static TwitterResponse<TwitterUser> Show(OAuthTokens tokens, string username)
         {
             return Show(tokens, username, null);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Show[@name="ByUsername"]/*'/>
-        public static TwitterUser Show(string username)
+        public static TwitterResponse<TwitterUser> Show(string username)
         {
             return Show(null, username, null);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Search[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Search[@name="WithTokensAndOptions"]/*'/>
-        public static TwitterUserCollection Search(OAuthTokens tokens, string query, UserSearchOptions options)
+        public static TwitterResponse<TwitterUserCollection> Search(OAuthTokens tokens, string query, UserSearchOptions options)
         {
             Commands.UserSearchCommand command = new Commands.UserSearchCommand(tokens, query, options);
 
-            TwitterUserCollection result = Core.CommandPerformer<TwitterUserCollection>.PerformAction(command);
-
-            if (result != null)
-                result.PagedCommand = command;
-
-            return result;
+            return Core.CommandPerformer.PerformAction(command);
         }
 
         /// <include file='TwitterUser.xml' path='TwitterUser/Search[@name="Common"]/*'/>
         /// <include file='TwitterUser.xml' path='TwitterUser/Search[@name="WithTokens"]/*'/>
-        public static TwitterUserCollection Search(OAuthTokens tokens, string query)
+        public static TwitterResponse<TwitterUserCollection> Search(OAuthTokens tokens, string query)
         {
             return Search(tokens, query, null);
         }
 
-        public static TwitterUserCollection Lookup(OAuthTokens tokens, LookupUsersOptions options)
+        /// <summary>
+        /// Return up to 100 users worth of extended information, specified by either ID, screen name, or combination of the two.
+        /// </summary>
+        /// <param name="tokens">The tokens.</param>
+        /// <param name="options">The options.</param>
+        /// <returns></returns>
+        public static TwitterResponse<TwitterUserCollection> Lookup(OAuthTokens tokens, LookupUsersOptions options)
         {
             Commands.LookupUsersCommand command = new Commands.LookupUsersCommand(tokens, options);
 
-            return Core.CommandPerformer<TwitterUserCollection>.PerformAction(command);
+            return Core.CommandPerformer.PerformAction(command);
         }
 
-        #region Account update methods
+        #region Retweeted By
         /// <summary>
-        /// Sets one or more hex values that control the color scheme of the authenticating user's profile page on twitter.com
+        /// Show user objects of up to 100 members who retweeted the status.
         /// </summary>
         /// <param name="tokens">The tokens.</param>
+        /// <param name="statusId">The status id.</param>
         /// <param name="options">The options.</param>
-        /// <returns>
-        /// The user, with updated data, as a <see cref="TwitterUser"/>
-        /// </returns>
-        public static TwitterUser UpdateProfileColors(OAuthTokens tokens, UpdateProfileColorsOptions options)
+        /// <returns>A collection of user objects.</returns>
+        public static TwitterResponse<TwitterUserCollection> RetweetedBy(OAuthTokens tokens, decimal statusId, RetweetedByOptions options)
         {
-            Commands.UpdateProfileColorsCommand command = new Twitterizer.Commands.UpdateProfileColorsCommand(tokens, options);
+            Commands.RetweetedByCommand command = new Commands.RetweetedByCommand(tokens, statusId, options);
 
-            return CommandPerformer<TwitterUser>.PerformAction(command);
+            return Core.CommandPerformer.PerformAction(command);
         }
 
         /// <summary>
-        /// Updates the authenticating user's profile image. 
+        /// Show user objects of up to 100 members who retweeted the status.
         /// </summary>
         /// <param name="tokens">The tokens.</param>
-        /// <param name="image">The avatar image for the profile. Must be a valid GIF, JPG, or PNG image of less than 700 kilobytes in size. Images with width larger than 500 pixels will be scaled down.</param>
+        /// <param name="statusId">The status id.</param>
+        /// <returns>A collection of user objects.</returns>
+        public static TwitterResponse<TwitterUserCollection> RetweetedBy(OAuthTokens tokens, decimal statusId)
+        {
+            return RetweetedBy(tokens, statusId, null);
+        }
+
+        /// <summary>
+        /// Show user ids of up to 100 members who retweeted the status.
+        /// </summary>
+        /// <param name="tokens">The tokens.</param>
+        /// <param name="statusId">The status id.</param>
         /// <param name="options">The options.</param>
-        /// <returns>
-        /// The user, with updated data, as a <see cref="TwitterUser"/>
-        /// </returns>
-        public static TwitterUser UpdateProfileImage(OAuthTokens tokens, TwitterImage image, OptionalProperties options)
+        /// <returns>A collection of user ids.</returns>
+        public static TwitterResponse<UserIdCollection> RetweetedByIds(OAuthTokens tokens, decimal statusId, RetweetedByIdsOptions options)
         {
-            Commands.UpdateProfileImageCommand command = new Twitterizer.Commands.UpdateProfileImageCommand(tokens, image, options);
+            Commands.RetweetedByIdsCommand command = new Commands.RetweetedByIdsCommand(tokens, statusId, options);
 
-            return CommandPerformer<TwitterUser>.PerformAction(command);
+            return Core.CommandPerformer.PerformAction(command);
         }
 
         /// <summary>
-        /// Updates the authenticating user's profile image.
+        /// Show user ids of up to 100 members who retweeted the status.
         /// </summary>
         /// <param name="tokens">The tokens.</param>
-        /// <param name="image">The avatar image for the profile. Must be a valid GIF, JPG, or PNG image of less than 700 kilobytes in size. Images with width larger than 500 pixels will be scaled down.</param>
-        /// <returns>
-        /// The user, with updated data, as a <see cref="TwitterUser"/>
-        /// </returns>
-        public static TwitterUser UpdateProfileImage(OAuthTokens tokens, TwitterImage image)
+        /// <param name="statusId">The status id.</param>
+        /// <returns>A collection of user ids.</returns>
+        public static TwitterResponse<UserIdCollection> RetweetedByIds(OAuthTokens tokens, decimal statusId)
         {
-            return UpdateProfileImage(tokens, image, null);
+            return RetweetedByIds(tokens, statusId, null);
         }
         #endregion
     }
