@@ -1,3 +1,25 @@
+// This file is part of Smuxi and is licensed under the terms of MIT/X11
+//
+// Copyright (c) 2007 Mirco Bauer <meebey@meebey.net>
+//
+// Permission is hereby granted, free of charge, to any person obtaining a copy
+// of this software and associated documentation files (the "Software"), to deal
+// in the Software without restriction, including without limitation the rights
+// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+// copies of the Software, and to permit persons to whom the Software is
+// furnished to do so, subject to the following conditions:
+//
+// The above copyright notice and this permission notice shall be included in
+// all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+// THE SOFTWARE.
+//
 // FastSerializer.cs.  Provides SerializationWriter and SerializationReader classes to help high speed serialization.
 // This short example shows how they're used:
 //
@@ -105,6 +127,10 @@ namespace Smuxi.Common
         /// send the length of the array which is needed when it is retrieved </summary>
 
         public override void Write(byte[] b) {
+            WriteBytes(b);
+        }
+
+        public void WriteBytes(byte[] b) {
          if (b==null) {
            Write(-1);
          } else {
@@ -253,9 +279,14 @@ namespace Smuxi.Common
         /// <summary> Adds the SerializationWriter buffer to the SerializationInfo at the end of GetObjectData(). </summary>
         public void AddToInfo(SerializationInfo info)
         {
-            byte[] b = ((MemoryStream) BaseStream).ToArray();
+            var b = GetData();
             info.AddValue("X", b, typeof(byte[]));
         }
+
+        public byte[] GetData()
+        {
+            return ((MemoryStream) BaseStream).ToArray();
+        }
     }
 
     /// <summary> SerializationReader.  Extends BinaryReader to add additional data types,
@@ -282,6 +313,12 @@ namespace Smuxi.Common
             return new SerializationReader(ms);
         }
 
+        public static SerializationReader GetReader(byte[] data)
+        {
+            MemoryStream ms = new MemoryStream(data);
+            return new SerializationReader(ms);
+        }
+
         /// <summary> Reads a string from the buffer.  Overrides the base implementation so it can cope with nulls. </summary>
         public override string ReadString()
         {
@@ -316,7 +353,7 @@ namespace Smuxi.Common
         /// <summary> Reads a DateTime from the buffer. </summary>
         public DateTime ReadDateTime()
         {
-            return new DateTime(ReadInt64());
+            return new DateTime(ReadInt64(), DateTimeKind.Utc);
         }
 
         public IList ReadList()
