@@ -1,5 +1,4 @@
-//
-// Options.cs
+// This file is part of Smuxi and is licensed under the terms of MIT/X11
 //
 // Authors:
 //  Jonathan Pryor <jpryor@novell.com>
@@ -765,7 +764,7 @@ namespace Mono.Options
 			return false;
 		}
 
-		private readonly Regex ValueOption = new Regex (
+		static readonly Regex ValueOption = new Regex (
 			@"^(?<flag>--|-|/)(?<name>[^:=]+)((?<sep>[:=])(?<value>.*))?$");
 
 		protected bool GetOptionParts (string argument, out string flag, out string name, out string sep, out string value)
