@@ -41,9 +41,22 @@ namespace Smuxi.Engine
         }
     }
 
+    internal class ErrorReceivedEventArgs : EventArgs
+    {
+        public HttpStatusCode StatusCode { get; private set; }
+        public string StatusDescription { get; private set; }
+
+        public ErrorReceivedEventArgs(HttpStatusCode code, string description)
+        {
+            StatusCode = code;
+            StatusDescription = description;
+        }
+    }
+
     internal class CampfireEventStream : IDisposable
     {
         public EventHandler<MessageReceivedEventArgs> MessageReceived;
+        public EventHandler<ErrorReceivedEventArgs> ErrorReceived;
 
         HttpWebRequest Request { get; set; }
         GroupChatModel Chat { get; set; }
@@ -99,7 +112,20 @@ namespace Smuxi.Engine
                     ParseStream();
                 } catch (TimeoutException) {
                     // Not to worry, let's just connect again
-                } catch (WebException) {
+                } catch (WebException e) {
+                    if (e.Status == WebExceptionStatus.ProtocolError) {
+                        var resp = (HttpWebResponse) e.Response;
+                        if (resp.StatusCode == HttpStatusCode.Unauthorized ||
+                            resp.StatusCode == HttpStatusCode.Forbidden) {
+                            if (ErrorReceived != null) {
+                                ErrorReceived(this, new ErrorReceivedEventArgs(resp.StatusCode, resp.StatusDescription));
+                            }
+
+                            return;
+                        }
+                        // it's not such a bad error, sleep for a bit before trying again
+                        Thread.Sleep(TimeSpan.FromSeconds(5));
+                    }
                 }
             }
         }
@@ -114,37 +140,27 @@ namespace Smuxi.Engine
 
             using (StreamReader reader = new StreamReader(res.GetResponseStream()))
             {
-                /* Stupid but easy way to figure out when we've reached the end of a JSON object */
-                int brackets = 0;
                 StringBuilder bld = new StringBuilder();
 
                 while (!reader.EndOfStream) {
-                    var line = reader.ReadLine();
+                    var c = reader.Read();
 
-                    for (int i = 0; i < line.Length; i++) {
-                        bld.Append(line[i]);
-                        switch (line[i]) {
-                            case '{':
-                                brackets++;
-                                break;
-                            case '}':
-                                brackets--;
-                                break;
-                            default:
-                                continue;
-                        }
-
-                        if (brackets == 0) {
-                            var str = bld.ToString().Trim();
-                            bld.Length = 0;
-                            var message = JsonSerializer.DeserializeFromString<Message>(str);
-                            if (MessageReceived != null) {
-                                var args = new MessageReceivedEventArgs(Chat, message);
-                                MessageReceived(this, args);
-                            }
-                            LastMessage = message.Id;
-                        }
+                    /* The server uses CR to indicate when each message ends */
+                    if (c != '\r') {
+                        bld.Append((char)c);
+                        continue;
                     }
+
+                    var str = bld.ToString();
+                    bld.Length = 0;
+
+                    var message = JsonSerializer.DeserializeFromString<Message>(str);
+                    if (MessageReceived != null) {
+                        var args = new MessageReceivedEventArgs(Chat, message);
+                        MessageReceived(this, args);
+                    }
+
+                    LastMessage = message.Id;
                 }
 
                 reader.Close();
