@@ -1,6 +1,6 @@
 // Smuxi - Smart MUltipleXed Irc
 // 
-// Copyright (c) 2012-2013 Mirco Bauer <meebey@meebey.net>
+// Copyright (c) 2012-2014 Mirco Bauer <meebey@meebey.net>
 // 
 // Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 // 
@@ -101,7 +101,7 @@ namespace Smuxi.Engine
             var builder = CreateMessageBuilder().
                 AppendEventPrefix().
                 AppendHeader(_("JabbR Commands"));
-            cmd.FrontendManager.AddMessageToChat(cmd.Chat, builder.ToMessage());
+            Session.AddMessageToFrontend(cmd, builder.ToMessage());
 
             string[] help = {
                 "connect jabbr username password",
@@ -112,7 +112,7 @@ namespace Smuxi.Engine
                 builder = CreateMessageBuilder();
                 builder.AppendEventPrefix();
                 builder.AppendText(line);
-                cmd.FrontendManager.AddMessageToChat(cmd.Chat, builder.ToMessage());
+                Session.AddMessageToFrontend(cmd, builder.ToMessage());
             }
         }
 
@@ -200,7 +200,7 @@ namespace Smuxi.Engine
                 // for some reason and then fallbacks to LongPollingTransport
                 // this takes 10 seconds though, so let's go LP directly
                 Func<IClientTransport> transport = null;
-                if (Type.GetType("Mono.Runtime") == null) {
+                if (!Platform.IsMono) {
                     transport = () => new AutoTransport(new DefaultHttpClient());
                 } else {
                     transport = () => new LongPollingTransport();
@@ -244,6 +244,20 @@ namespace Smuxi.Engine
                     ToMessage();
             Session.AddMessageToChat(ProtocolChat, msg);
 
+            if (!Server.ValidateServerCertificate) {
+                var whitelist = Session.CertificateValidator.HostnameWhitelist;
+                lock (whitelist) {
+                    var hostname = Server.Hostname;
+                    if (hostname.StartsWith("http://") ||
+                        hostname.StartsWith("https://")) {
+                        hostname = new Uri(hostname).Host;
+                    }
+                    if (!whitelist.Contains(hostname)) {
+                        whitelist.Add(hostname);
+                    }
+                }
+            }
+
             var res = Client.Connect(Server.Username, Server.Password);
             res.Wait();
             // HACK: this event can only be subscribed if we have made an
@@ -465,7 +479,19 @@ namespace Smuxi.Engine
             if (sender != Me) {
                 builder.MarkHighlights();
             }
-            Session.AddMessageToChat(chat, builder.ToMessage());
+            var message = builder.ToMessage();
+            Session.AddMessageToChat(chat, message);
+
+            if (sender == Me) {
+                // server echos our sent messages for us
+                OnMessageSent(
+                    new MessageEventArgs(chat, message, null, chat.ID)
+                );
+            } else {
+                OnMessageReceived(
+                    new MessageEventArgs(chat, message, name, chat.ID)
+                );
+            }
         }
 
         void OnMeMessageReceived(string userName, string content, string roomName)
@@ -483,6 +509,10 @@ namespace Smuxi.Engine
             }
             var msg = builder.ToMessage();
             Session.AddMessageToChat(chat, msg);
+
+            OnMessageReceived(
+                new MessageEventArgs(chat, msg, userName, roomName)
+            );
         }
 
         void OnUserJoined(User user, string room, bool isOwner)
