@@ -1,13 +1,7 @@
 /*
- * $Id: ChannelPage.cs 137 2006-11-06 18:49:57Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Engine/ChannelPage.cs $
- * $Rev: 137 $
- * $Author: meebey $
- * $Date: 2006-11-06 19:49:57 +0100 (Mon, 06 Nov 2006) $
- *
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2008 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2008, 2011 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -39,7 +33,7 @@ namespace Smuxi.Engine
         public SessionChatModel(string id, string name) :
                            base(id, name, ChatType.Session, null)
         {
+            Position = 0;
         }
     }
 }
-
