@@ -38,6 +38,14 @@ namespace Smuxi.Engine
         public IWebProxy SystemWebProxy { get; set; }
         public WebProxy DefaultWebProxy { get; set; }
 
+        static ProxySettings()
+        {
+            try {
+                WorkaroundNoProxyMonoBug();
+            } catch {
+            }
+        }
+
         public ProxySettings()
         {
             ProxyType = ProxyType.None;
@@ -119,9 +127,9 @@ namespace Smuxi.Engine
                     SystemWebProxy = null;
                     break;
                 case ProxyType.System:
-                    var proxy = WebRequest.GetSystemWebProxy();
                     // TODO: add GNOME (gconf) support
                     var no_proxy = Environment.GetEnvironmentVariable("no_proxy");
+                    var proxy = WebRequest.GetSystemWebProxy();
                     if (!String.IsNullOrEmpty(no_proxy) && proxy is WebProxy) {
                         var webProxy = (WebProxy) proxy;
                         // BypassArrayList expects regexes while no_proxy
@@ -162,5 +170,31 @@ namespace Smuxi.Engine
                     break;
             }
         }
+
+        static void WorkaroundNoProxyMonoBug()
+        {
+            // HACK: workaround bug in Mono 2.10.8 throwing
+            // ArgumentOutOfRangeException because it always tries to remove
+            // *.local from the no_proxy envrionment variable, see:
+            // https://www.smuxi.org/issues/show/873
+            var no_proxy = Environment.GetEnvironmentVariable("no_proxy");
+            if (no_proxy == null) {
+                // nothing to workaround
+                return;
+            }
+
+            try {
+                WebRequest.GetSystemWebProxy();
+            } catch (ArgumentOutOfRangeException) {
+#if LOG4NET
+                f_Logger.Debug("WorkaroundNoProxyMonoBug(): enabling no_proxy workaround...");
+#endif
+                if (!no_proxy.Contains("*.local")) {
+                    var no_proxy_with_local = no_proxy + ",*.local";
+                    Environment.SetEnvironmentVariable("no_proxy",
+                                                       no_proxy_with_local);
+                }
+            }
+        }
     }
 }
