@@ -1,7 +1,7 @@
 /*
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2007, 2010, 2012-2014 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2007, 2010, 2012-2014, 2017-2018 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -32,6 +32,7 @@ namespace Smuxi.Engine
     {
         public bool UseEncryption { get; set; }
         public bool ValidateServerCertificate { get; set; }
+        public string ClientCertificateFilename { get; set; }
         public string Protocol { get; set; }
         public string Hostname { get; set; }
         public int Port { get; set; }
@@ -60,6 +61,28 @@ namespace Smuxi.Engine
         {
         }
 
+        public ServerModel(ServerModel server)
+        {
+            if (server == null) {
+                throw new ArgumentNullException("server");
+            }
+
+            UseEncryption = server.UseEncryption;
+            ValidateServerCertificate = server.ValidateServerCertificate;
+            ClientCertificateFilename = server.ClientCertificateFilename;
+            Protocol = server.Protocol;
+            Hostname = server.Hostname;
+            Port = server.Port;
+            Network = server.Network;
+            Nickname = server.Nickname;
+            Realname = server.Realname;
+            Username = server.Username;
+            Password = server.Password;
+            OnStartupConnect = server.OnStartupConnect;
+            OnConnectCommands = new List<string>(server.OnConnectCommands);
+            ServerID = server.ServerID;
+        }
+
         protected ServerModel(SerializationInfo info, StreamingContext ctx)
         {
             Protocol = info.GetString("_Protocol");
@@ -100,6 +123,9 @@ namespace Smuxi.Engine
                         ValidateServerCertificate = (bool)e.Value;
                         foundValidation = true;
                         break;
+                    case "ClientCertificateFilename":
+                        ClientCertificateFilename = (string) e.Value;
+                        break;
                 }
             }
             if (foundServerID == false) {
@@ -132,6 +158,12 @@ namespace Smuxi.Engine
             if (Realname != null) {
                 info.AddValue("_Realname", Realname);
             }
+            // HACK: skip ClientCertificateFilename if it has no value as it
+            // breaks older ServerModel implementations that relied on automatic
+            // serialization which was the case in < 0.8.11
+            if (!String.IsNullOrEmpty(ClientCertificateFilename)) {
+                info.AddValue("ClientCertificateFilename", ClientCertificateFilename);
+            }
             info.AddValue("_Protocol", Protocol);
             info.AddValue("_Hostname", Hostname);
             info.AddValue("_Port", Port);
@@ -175,6 +207,7 @@ namespace Smuxi.Engine
             UseEncryption = (bool) config[ConfigKeyPrefix + "UseEncryption"];
             ValidateServerCertificate =
                 (bool) config[ConfigKeyPrefix + "ValidateServerCertificate"];
+            ClientCertificateFilename = (string) config[ConfigKeyPrefix + "ClientCertificateFilename"];
             if (config[ConfigKeyPrefix + "OnStartupConnect"] != null) {
                 OnStartupConnect = (bool) config[ConfigKeyPrefix + "OnStartupConnect"];
             }
@@ -196,6 +229,8 @@ namespace Smuxi.Engine
             config[ConfigKeyPrefix + "UseEncryption"] = UseEncryption;
             config[ConfigKeyPrefix + "ValidateServerCertificate"] =
                 ValidateServerCertificate;
+            config[ConfigKeyPrefix + "ClientCertificateFilename"] =
+                ClientCertificateFilename;
             config[ConfigKeyPrefix + "OnStartupConnect"] = OnStartupConnect;
             config[ConfigKeyPrefix + "OnConnectCommands"] = OnConnectCommands;
         }
