@@ -27,12 +27,22 @@
  */
 
 using System;
+using System.Runtime.Serialization;
 
 namespace Smuxi.Engine
 {
+    [DataContract]
     public enum MessageType
     {
         Normal,
-        Event
+        Event,
+        ChatStateComposing,
+        ChatStatePaused,
+        ChatStateReset,
+        PresenceStateOffline,
+        PresenceStateAway,
+        PresenceStateOnline,
+        ChatNameChanged,
+        PersonChatPersonChanged
     }
 }
