@@ -101,7 +101,7 @@ namespace Smuxi.Frontend.Curses
 
         private void _CommandUnknown(CommandModel cd)
         {
-            cd.FrontendManager.AddTextToCurrentChat("-!- " +
+            cd.FrontendManager.AddTextToChat(cd.Chat, "-!- " +
                                 String.Format(Catalog.GetString(
                                               "Unknown Command: {0}"),
                                               cd.Command));
