@@ -37,6 +37,8 @@ namespace Smuxi.Frontend.Gnome
 #if LOG4NET
         private static readonly log4net.ILog f_Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
 #endif
+        string ReportSubject { get; set; }
+        string ReportDescription { get; set; }
 
         public CrashDialog(Gtk.Window parent, Exception e) : base(null, parent, Gtk.DialogFlags.Modal)
         {
@@ -85,15 +87,41 @@ namespace Smuxi.Frontend.Gnome
             if (e.InnerException != null) {
                 message = "Inner-Exception Type:\n"+e.InnerException.GetType()+"\n\n"+
                           "Inner-Exception Message:\n"+e.InnerException.Message+"\n\n"+
-                          "Inner-Exception StackTrace:\n"+e.InnerException.StackTrace+"\n";
+                          "Inner-Exception StackTrace:\n"+e.InnerException.StackTrace+"\n\n";
+                if (e.StackTrace != null &&
+                    e.InnerException.StackTrace.Contains("System.Runtime.Remoting")) {
+                    message += "Inner-Exception.ToString():\n"+e.InnerException.ToString()+"\n\n";
+                }
             }
             message += "Exception Type:\n"+e.GetType()+"\n\n"+
                        "Exception Message:\n"+e.Message+"\n\n"+
-                       "Exception StackTrace:\n"+e.StackTrace;
+                       "Exception StackTrace:\n"+e.StackTrace+"\n\n";
+            if (e.StackTrace != null &&
+                e.StackTrace.Contains("System.Runtime.Remoting")) {
+                message += "Exception.ToString():\n"+e.ToString()+"\n\n";
+            }
             tv.Buffer.Text = message;
+            ReportSubject = "Exception: " + HtmlEncodeLame(e.Message);
+            ReportDescription = String.Format(
+                "<pre>{0}</pre>",
+                HtmlEncodeLame("\n" + message)
+            );
             
             ShowAll();
-       }
+        }
+
+        private string HtmlEncodeLame(string text)
+        {
+            if (text == null) {
+                return String.Empty;
+            }
+
+            return text.Replace("&", "%26").
+                        Replace(" ", "%20").
+                        Replace("\n", "%0A").
+                        Replace("<", "%3C").
+                        Replace(">", "%3E");
+        }
        
         public static void Show(Gtk.Window parent, Exception ex)
         {
@@ -109,7 +137,16 @@ namespace Smuxi.Frontend.Gnome
                 res = base.Run();
                 if (res == -1) {
                     try {
-                        System.Diagnostics.Process.Start("http://www.smuxi.org/newticket");
+                        System.Diagnostics.Process.Start(
+                            String.Format(
+                                "http://www.smuxi.org/issues/new" +
+                                    "?issue[tracker_id]=1" +
+                                    "&issue[subject]={0}" +
+                                    "&issue[description]={1}",
+                                ReportSubject,
+                                ReportDescription
+                            )
+                        );
                     } catch (Exception ex) {
 #if LOG4NET
                         f_Logger.Error(ex);
