@@ -1,13 +1,7 @@
 /*
- * $Id$
- * $URL$
- * $Rev$
- * $Author$
- * $Date$
- *
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2005-2013, 2015 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -46,6 +40,7 @@ namespace Smuxi.Frontend.Gnome
         private EngineManager _EngineManager;
         private Gtk.Button    _EditButton;
         private Gtk.Button    _DeleteButton;
+        new Gtk.Window Parent { get; set; }
 
         public string SelectedEngine {
             get {
@@ -67,17 +62,18 @@ namespace Smuxi.Frontend.Gnome
             }
         }
 
-        public EngineManagerDialog(EngineManager engineManager)
+        public EngineManagerDialog(Gtk.Window parent, EngineManager engineManager) :
+                              base(null, parent, Gtk.DialogFlags.Modal)
         {
-            Trace.Call(engineManager);
+            Trace.Call(parent, engineManager);
             
             if (engineManager == null) {
                 throw new ArgumentNullException("engineManager");
             }
-            
+
+            Parent = parent;
             _EngineManager = engineManager;
             
-            Modal = true;
             Title = "Smuxi - " + _("Engine Manager");
             SetPosition(Gtk.WindowPosition.CenterAlways);
 
@@ -208,21 +204,24 @@ namespace Smuxi.Frontend.Gnome
             string engine = _SelectedEngine;
             try {
                 _EngineManager.Connect(engine);
-                var engineVersion = _EngineManager.EngineVersion;
-                var frontendVersion = Frontend.Version;
-                if ((engineVersion >= new Version("0.8") &&
-                     engineVersion.Major != frontendVersion.Major) ||
-                    (engineVersion < new Version("0.8") &&
-                     (engineVersion.Major != frontendVersion.Major ||
-                      engineVersion.Minor != frontendVersion.Minor))) {
-                    throw new ApplicationException(String.Format(
-                                _("Your frontend version ({0}) does not match the engine version ({1})!"),
-                                Frontend.Version, _EngineManager.EngineVersion));
+                var engineProtocolVersion = _EngineManager.EngineProtocolVersion;
+                var frontendProtocolVersion = new Version(0, 0);
+                if (engineProtocolVersion.Major != frontendProtocolVersion.Major) {
+                    throw new ApplicationException(
+                        String.Format(
+                            _("Your frontend is not compatible with the engine!\n" +
+                              "Engine Version: {0} Frontend Version: {1}\n" +
+                              "Engine Protocol: {2} Frontend Protocol: {3}"),
+                            _EngineManager.EngineAssemblyVersion, Frontend.Version,
+                            engineProtocolVersion, frontendProtocolVersion
+                        )
+                    );
                 }
                 
                 Frontend.Session = _EngineManager.Session;
                 Frontend.UserConfig = _EngineManager.UserConfig;
-                Frontend.EngineVersion = _EngineManager.EngineVersion;
+                Frontend.EngineAssemblyVersion = _EngineManager.EngineAssemblyVersion;
+                Frontend.EngineProtocolVersion = _EngineManager.EngineProtocolVersion;
                 Frontend.ConnectEngineToGUI();
             } catch (Exception ex) {
 #if LOG4NET
@@ -262,7 +261,7 @@ namespace Smuxi.Frontend.Gnome
         private void _OnNewButtonPressed()
         {
             EngineAssistant assistant = new EngineAssistant(
-                this,
+                Parent,
                 Frontend.FrontendConfig
             );
             assistant.Cancel += delegate {
@@ -270,7 +269,7 @@ namespace Smuxi.Frontend.Gnome
                 
                 // Restart the Dialog
                 // HACK: holy shit, please refactor this mess!
-                EngineManagerDialog dialog = new EngineManagerDialog(_EngineManager);
+                var dialog = new EngineManagerDialog(Parent, _EngineManager);
                 dialog.Run();
                 dialog.Destroy();
             };
@@ -279,7 +278,7 @@ namespace Smuxi.Frontend.Gnome
                 
                 // Restart the Dialog
                 // HACK: holy shit, please refactor this mess!
-                EngineManagerDialog dialog = new EngineManagerDialog(_EngineManager);
+                var dialog = new EngineManagerDialog(Parent, _EngineManager);
                 dialog.Run();
                 dialog.Destroy();
             };
@@ -289,7 +288,7 @@ namespace Smuxi.Frontend.Gnome
         private void _OnEditButtonPressed()
         {
             EngineAssistant assistant = new EngineAssistant(
-                this,
+                Parent,
                 Frontend.FrontendConfig,
                 _SelectedEngine
             );
@@ -298,7 +297,7 @@ namespace Smuxi.Frontend.Gnome
 
                 // Restart the Dialog
                 // HACK: holy shit, please refactor this mess!
-                EngineManagerDialog dialog = new EngineManagerDialog(_EngineManager);
+                var dialog = new EngineManagerDialog(Parent, _EngineManager);
                 dialog.Run();
                 dialog.Destroy();
             };
@@ -307,7 +306,7 @@ namespace Smuxi.Frontend.Gnome
                 
                 // Restart the Dialog
                 // HACK: holy shit, please refactor this mess!
-                EngineManagerDialog dialog = new EngineManagerDialog(_EngineManager);
+                var dialog = new EngineManagerDialog(Parent, _EngineManager);
                 dialog.Run();
                 dialog.Destroy();
             };
