@@ -219,11 +219,13 @@ namespace Smuxi.Frontend.Gnome
             if (!IsEnabled ||
                 e.Message.TimeStamp <= chatView.SyncedLastSeenHighlight ||
                 (MainWindow.HasToplevelFocus &&
-                 chatView.LabelWidget.IsDrawable)) {
+                 (ChatViewManager.CurrentChatView == chatView ||
+                  MainWindow.ChatTreeView.IsVisible(chatView)))) {
                 // no need to show a notification for:
                 // - disabled chats
                 // - seen highlights
-                // - main window has focus and the chat tab is visible
+                // - main window has focus and the chat is active or the chat
+                //   row is visible
                 return;
             }
 
@@ -336,7 +338,7 @@ namespace Smuxi.Frontend.Gnome
                 notification.AddAction("show", _("Show"), delegate {
                     try {
                         MainWindow.PresentWithServerTime();
-                        MainWindow.Notebook.CurrentChatView = chatView;
+                        ChatViewManager.CurrentChatView = chatView;
                         notification.Close();
                     } catch (Exception ex) {
 #if LOG4NET
@@ -394,7 +396,7 @@ namespace Smuxi.Frontend.Gnome
                 return;
             }
 
-            var currentChatView = MainWindow.Notebook.CurrentChatView;
+            var currentChatView = ChatViewManager.CurrentChatView;
             if (currentChatView == null) {
                 return;
             }
@@ -409,7 +411,7 @@ namespace Smuxi.Frontend.Gnome
                 return;
             }
 
-            var currentChatView = MainWindow.Notebook.CurrentChatView;
+            var currentChatView = ChatViewManager.CurrentChatView;
             if (currentChatView == null) {
                 return;
             }
