@@ -1,13 +1,7 @@
 /*
- * $Id: PreferencesDialog.cs 142 2007-01-02 22:19:08Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-GNOME/PreferencesDialog.cs $
- * $Rev: 142 $
- * $Author: meebey $
- * $Date: 2007-01-02 23:19:08 +0100 (Tue, 02 Jan 2007) $
- *
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2005-2008 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2005-2008, 2010, 2012-2013, 2016 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -30,43 +24,58 @@ using System;
 using System.Collections.Generic;
 using Smuxi.Common;
 using Smuxi.Engine;
+#if GTK_SHARP_3
+using TreeModel = Gtk.ITreeModel;
+#else
+using TreeModel = Gtk.TreeModel;
+#endif
+using UI = Gtk.Builder.ObjectAttribute;
 
 namespace Smuxi.Frontend.Gnome
 {
-    public class ServerListView
+    public class ServerListView : Gtk.Bin
     {
         private ServerListController     _Controller;
         private Gtk.Window               _Parent;
         
 #region Widgets
-        [Glade.Widget("ServersTreeView")]
+        [UI("ServersTreeView")]
         private Gtk.TreeView             _TreeView;
         private Gtk.TreeStore            _TreeStore;
-        [Glade.Widget("ServersAddButton")]
-        private Gtk.Button               _AddButton;
-        [Glade.Widget("ServersEditButton")]
-        private Gtk.Button               _EditButton;
-        [Glade.Widget("ServersRemoveButton")]
-        private Gtk.Button               _RemoveButton;
+        [UI("EditServerToolButton")]
+        Gtk.ToolButton _EditButton;
+        [UI("RemoveServerToolButton")]
+        Gtk.ToolButton _RemoveButton;
 #endregion
         
-        public ServerListView(Gtk.Window parent, Glade.XML gladeXml)
+        public ServerListView(Gtk.Window parent)
         {
-            Trace.Call(parent, gladeXml);
-            
+            Trace.Call(parent);
+
             if (parent == null) {
                 throw new ArgumentNullException("parent");
             }
-            
+
             _Parent = parent;
+
+            Build();
+            Init();
+            ShowAll();
+        }
+
+        void Build()
+        {
+            global::Stetic.BinContainer.Attach(this);
+            var builder = new Gtk.Builder(null, "ServerListWidget.ui", null);
+            builder.Autoconnect(this);
+            var box = (Gtk.Widget) builder.GetObject("ServerListBox");
+            Add(box);
+        }
+
+        void Init()
+        {
             _Controller = new ServerListController(Frontend.UserConfig);
-            
-            gladeXml.BindFields(this);
-            
-            _AddButton.Clicked += new EventHandler(OnAddButtonClicked);
-            _EditButton.Clicked += new EventHandler(OnEditButtonClicked);
-            _RemoveButton.Clicked += new EventHandler(OnRemoveButtonClicked);
-            
+
             _TreeView.AppendColumn(_("Protocol"), new Gtk.CellRendererText(), "text", 1); 
             _TreeView.AppendColumn(_("Hostname"), new Gtk.CellRendererText(), "text", 2); 
             
@@ -74,6 +83,8 @@ namespace Smuxi.Frontend.Gnome
                                            typeof(string), // protocol
                                            typeof(string) // hostname
                                            );
+            _TreeStore.SetSortColumnId(0, Gtk.SortType.Ascending);
+            _TreeStore.SetSortFunc(0, SortTreeStore);
             _TreeView.RowActivated += OnTreeViewRowActivated;
             _TreeView.Selection.Changed += OnTreeViewSelectionChanged;
             _TreeView.Model = _TreeStore;
@@ -131,7 +142,9 @@ namespace Smuxi.Frontend.Gnome
         {
             Trace.Call();
             
-            ServerDialog dialog = new ServerDialog(_Parent, null, Frontend.Session.GetSupportedProtocols(), _Controller.GetNetworks());
+            var dialog = new ServerDialog(_Parent, null,
+                                          Frontend.Session.GetSupportedProtocols(),
+                                          _Controller.GetNetworks());
             try {
                 int res = dialog.Run();
                 ServerModel server = dialog.GetServer();
@@ -157,7 +170,9 @@ namespace Smuxi.Frontend.Gnome
                 throw new ArgumentNullException("server");
             }
             
-            ServerDialog dialog = new ServerDialog(_Parent, server, Frontend.Session.GetSupportedProtocols(), _Controller.GetNetworks());
+            var dialog = new ServerDialog(_Parent, server,
+                                          Frontend.Session.GetSupportedProtocols(),
+                                          _Controller.GetNetworks());
             int res = dialog.Run();
             server = dialog.GetServer();
             dialog.Destroy();
@@ -191,7 +206,7 @@ namespace Smuxi.Frontend.Gnome
                 return;
             }
             
-            _Controller.RemoveServer(server.Protocol, server.Hostname);
+            _Controller.RemoveServer(server.Protocol, server.ServerID);
             _Controller.Save();
             
             // refresh the view
@@ -279,7 +294,32 @@ namespace Smuxi.Frontend.Gnome
                 Frontend.ShowException(ex);
             }
         }
-        
+
+        protected virtual int SortTreeStore(TreeModel model,
+                                            Gtk.TreeIter iter1,
+                                            Gtk.TreeIter iter2)
+        {
+            var server1 = (ServerModel) model.GetValue(iter1, 0);
+            var server2 = (ServerModel) model.GetValue(iter2, 0);
+            // protocol nodes don't have a ServerModel
+            if (server1 == null && server2 == null) {
+                return 0;
+            }
+            if (server2 == null) {
+                return 1;
+            }
+            if (server1 == null) {
+                return -1;
+            }
+            var s1 = String.Format("{0}/{1}:{2} ({3})",
+                                   server1.Protocol, server1.Hostname,
+                                   server1.Port, server1.ServerID);
+            var s2 = String.Format("{0}/{1}:{2} ({3})",
+                                   server2.Protocol, server2.Hostname,
+                                   server2.Port, server2.ServerID);
+            return s1.CompareTo(s2);
+        }
+
         private static string _(string msg)
         {
             return Mono.Unix.Catalog.GetString(msg);
