@@ -1,6 +1,6 @@
 // Smuxi - Smart MUltipleXed Irc
 //
-// Copyright (c) 2013-2014 Mirco Bauer <meebey@meebey.net>
+// Copyright (c) 2013-2015 Mirco Bauer <meebey@meebey.net>
 //
 // Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
 //
@@ -30,6 +30,7 @@ namespace Smuxi.Frontend.Gnome
 #endif
         public Gtk.TreeStore TreeStore { get; private set; }
         ThemeSettings ThemeSettings { get; set; }
+        Gtk.TreeViewColumn ActivityColumn { get; set; }
         int f_CurrentChatNumber;
 
         public ChatView CurrentChatView {
@@ -48,12 +49,11 @@ namespace Smuxi.Frontend.Gnome
                         return;
                     }
                 } else {
-                    iter = FindChatIter(value);
-                    if (Gtk.TreeIter.Zero.Equals(iter)) {
+                    if (!TryFindChatIter(value, out iter)) {
 #if LOG4NET
                         f_Logger.ErrorFormat(
-                            "set_CurrentChatView(): FindChatIter({0}) " +
-                            "returned Gtk.TreeIter.Zero, ignoring...", value
+                            "set_CurrentChatView(): TryFindChatIter({0}) " +
+                            "found no matching chat, ignoring...", value
                         );
 #endif
                         return;
@@ -133,6 +133,7 @@ namespace Smuxi.Frontend.Gnome
             column.Sizing = Gtk.TreeViewColumnSizing.Autosize;
             column.SetCellDataFunc(cellRenderer, new Gtk.TreeCellDataFunc(RenderChatViewActivity));
             AppendColumn(column);
+            ActivityColumn = column;
         }
 
         public virtual void Append(ChatView chatView)
@@ -171,7 +172,8 @@ namespace Smuxi.Frontend.Gnome
                 throw new ArgumentNullException("chatView");
             }
 
-            var iter = FindChatIter(chatView);
+            Gtk.TreeIter iter;
+            TryFindChatIter(chatView, out iter);
             if (!TreeStore.IterIsValid(iter)) {
                 return;
             }
@@ -186,7 +188,8 @@ namespace Smuxi.Frontend.Gnome
                 throw new ArgumentNullException("chatView");
             }
 
-            var iter = FindChatIter(chatView);
+            Gtk.TreeIter iter;
+            TryFindChatIter(chatView, out iter);
             //var path = TreeStore.GetPath(iter);
             //TreeStore.EmitRowChanged(path, iter);
             // HACK: this emits row_changed _and_ sort_iter_changed and there is
@@ -205,7 +208,8 @@ namespace Smuxi.Frontend.Gnome
             if (!GetVisibleRange(out visibleStart, out visibleEnd)) {
                 return false;
             }
-            var chatIter = FindChatIter(chatView);
+            Gtk.TreeIter chatIter;
+            TryFindChatIter(chatView, out chatIter);
             var chatPath = TreeStore.GetPath(chatIter);
             // we ignore 0 on purpose, say if a few pixels of a row are returned
             // as visible by GetVisibleRange() that is not good enough for us
@@ -233,6 +237,8 @@ namespace Smuxi.Frontend.Gnome
                 ModifyText(Gtk.StateType.Normal, ThemeSettings.ForegroundColor.Value);
             }
             ModifyFont(ThemeSettings.FontDescription);
+
+            ActivityColumn.Visible = (bool?) config["Interface/ShowActivityCounter"] ?? true;
         }
 
         protected virtual void RenderChatViewIcon(Gtk.TreeViewColumn column,
@@ -463,18 +469,21 @@ namespace Smuxi.Frontend.Gnome
             return parentIter;
         }
 
-        Gtk.TreeIter FindChatIter(ChatView view)
+        bool TryFindChatIter(ChatView view, out Gtk.TreeIter chatIter)
         {
-            Gtk.TreeIter chatIter = Gtk.TreeIter.Zero;
+			var found = false;
+			var foundIter = Gtk.TreeIter.Zero;
             TreeStore.Foreach((model, path, iter) => {
                 var candidate = (ChatView) model.GetValue(iter, 0);
                 if (candidate == view) {
-                    chatIter = iter;
+                    foundIter = iter;
+                    found = true;
                     return true;
                 }
                 return false;
             });
-            return chatIter;
+            chatIter = foundIter;
+            return found;
         }
 
         int GetRowNumber(Gtk.TreePath path)
