@@ -51,13 +51,39 @@ namespace Smuxi.Frontend.Gnome
 
             f_Widget.InitProtocols(supportedProtocols);
             f_Widget.InitNetworks(networks);
+
+            f_Widget.ProtocolComboBox.Changed += delegate {
+                CheckOkButton();
+            };
+            f_Widget.HostnameEntry.Changed += delegate {
+                CheckOkButton();
+            };
+            CheckOkButton();
+
             if (server != null) {
+                f_OkButton.Label = _("Save");
                 try {
                     f_Widget.Load(server);
                 } catch (Exception) {
                     Destroy();
                     throw;
                 }
+            } else {
+                f_OkButton.Label = _("Add");
+            }
+        }
+
+        protected virtual void CheckOkButton()
+        {
+            Trace.Call();
+
+            f_OkButton.Sensitive = true;
+            switch (f_Widget.ProtocolComboBox.ActiveText) {
+                case "Campfire":
+                    if (f_Widget.HostnameEntry.Text == ".campfirenow.com") {
+                        f_OkButton.Sensitive = false;
+                    }
+                    break;
             }
         }
 
@@ -65,5 +91,10 @@ namespace Smuxi.Frontend.Gnome
         {
             return f_Widget.GetServer();
         }
+
+        static string _(string msg)
+        {
+            return Mono.Unix.Catalog.GetString(msg);
+        }
     }
 }
