@@ -5,7 +5,7 @@
  * $Author: meebey $
  * $Date: 2007-04-17 23:17:37 +0200 (Tue, 17 Apr 2007) $
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2007 Mirco Bauer <meebey@meebey.net>
  * Copyright (c) 2007-2008 Jeffrey Mann Richardson <themann@indyfantasysports.net>
@@ -30,7 +30,7 @@
 using System.Reflection;
 using System.Runtime.CompilerServices;
 
-[assembly: AssemblyTitle("smuxi - SWF frontend")]
+[assembly: AssemblyTitle("Smuxi - SWF frontend")]
 [assembly: AssemblyCopyright("2005-2008 (C) Jeffrey Mann Richardson <themann@indyfantasysports.net>")]
 
 [assembly: AssemblyDelaySign(false)]
