@@ -43,17 +43,14 @@ namespace Smuxi.Frontend.Swf
         private static readonly string    _Name = "smuxi";
         private static readonly string    _UIName = "SWF (WinForms)";
         private static Version            _Version;
-        private static string             _VersionNumber;
         private static string             _VersionString;
         private static Version            _EngineVersion;
-        private static SplashScreenWindow _SplashScreenWindow;
         private static MainWindow         _MainWindow;
         private static FrontendConfig     _FrontendConfig;
         private static Session            _Session;
         private static UserConfig         _UserConfig;
         private static FrontendManager    _FrontendManager;
-        private static object             _UnhandledExceptionSyncRoot = new Object();
-        
+
         public static string Name {
             get {
                 return _Name;
@@ -139,7 +136,6 @@ namespace Smuxi.Frontend.Swf
             AssemblyProductAttribute pr = (AssemblyProductAttribute)asm.
                 GetCustomAttributes(typeof(AssemblyProductAttribute), false)[0];
             _Version = asm_name.Version;
-            _VersionNumber = asm_name.Version.ToString();
             _VersionString = pr.Product + " - " + _UIName + " frontend " + _Version;
 
 #if LOG4NET
@@ -151,8 +147,6 @@ namespace Smuxi.Frontend.Swf
             // called before any form is displayed.
             Application.EnableVisualStyles();
 
-            _SplashScreenWindow = new SplashScreenWindow();
-            
             _MainWindow = new MainWindow();
             // HACK: force creation of window handle, else the engine will have problems adding stuff
             IntPtr handle = _MainWindow.Handle;
@@ -175,9 +169,6 @@ namespace Smuxi.Frontend.Swf
                     InitLocalEngine();
                 }
             }
-            // TODO: Kill the SplashScreen Window
-            _SplashScreenWindow.Close();
-            
              /*TODO: Set the main message loop*/
             Application.Run(_MainWindow);
 #if LOG4NET
@@ -192,6 +183,8 @@ namespace Smuxi.Frontend.Swf
             _Session = new Engine.Session(Engine.Engine.Config,
                                           Engine.Engine.ProtocolManagerFactory,
                                           "local");
+            _Session.ExecuteOnStartupCommands();
+            _Session.ProcessAutoConnect();
             _Session.RegisterFrontendUI(_MainWindow.UI);
             _UserConfig = _Session.UserConfig;
             ConnectEngineToGUI();
